==> jc-1.4.0.tar.gz: soot/grimp/internal/GAssignStmt.h <==
// public class soot.grimp.internal.GAssignStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 10de3e3fdb8301f7 soot_grimp_internal_GAssignStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class cd586a93b432e783 soot_jimple_internal_JAssignStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JAssignStmt

#include "soot/jimple/internal/JAssignStmt.h"

#ifndef _JC_soot_grimp_internal_GAssignStmt_H_
#define _JC_soot_grimp_internal_GAssignStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GAssignStmt$sub_refs	_jc_soot_grimp_internal_GAssignStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs	_jc_soot_grimp_internal_GAssignStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$refs	_jc_soot_grimp_internal_GAssignStmt$refs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$nonrefs	_jc_soot_grimp_internal_GAssignStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$object	_jc_soot_grimp_internal_GAssignStmt$object;

typedef const struct _jc_soot_grimp_internal_GAssignStmt$vmethods	_jc_soot_grimp_internal_GAssignStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GAssignStmt$vtable	_jc_soot_grimp_internal_GAssignStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GAssignStmt$vtype	_jc_soot_grimp_internal_GAssignStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GAssignStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GAssignStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GAssignStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GAssignStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GAssignStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JAssignStmt$vmethods	soot_jimple_internal_JAssignStmt;
	_jc_soot_grimp_internal_GAssignStmt$vmethods	soot_grimp_internal_GAssignStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GAssignStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GAssignStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAssignStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GAssignStmt$refs {
    _jc_soot_grimp_internal_GAssignStmt$sub_refs	soot_grimp_internal_GAssignStmt;
    _jc_soot_jimple_internal_JAssignStmt$sub_refs	soot_jimple_internal_JAssignStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GAssignStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JAssignStmt$sub_nonrefs	soot_jimple_internal_JAssignStmt;
    _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs	soot_grimp_internal_GAssignStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GAssignStmt$object {
	_jc_soot_grimp_internal_GAssignStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GAssignStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GAssignStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GAssignStmt$vtype _jc_soot_grimp_internal_GAssignStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GAssignStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GAssignStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GAssignStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GAssignStmt.h <==
// public class soot.grimp.internal.GAssignStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 10de3e3fdb8301f7 soot_grimp_internal_GAssignStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class cd586a93b432e783 soot_jimple_internal_JAssignStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JAssignStmt

#include "soot/jimple/internal/JAssignStmt.h"

#ifndef _JC_soot_grimp_internal_GAssignStmt_H_
#define _JC_soot_grimp_internal_GAssignStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GAssignStmt$sub_refs	_jc_soot_grimp_internal_GAssignStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs	_jc_soot_grimp_internal_GAssignStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$refs	_jc_soot_grimp_internal_GAssignStmt$refs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$nonrefs	_jc_soot_grimp_internal_GAssignStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GAssignStmt$object	_jc_soot_grimp_internal_GAssignStmt$object;

typedef const struct _jc_soot_grimp_internal_GAssignStmt$vmethods	_jc_soot_grimp_internal_GAssignStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GAssignStmt$vtable	_jc_soot_grimp_internal_GAssignStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GAssignStmt$vtype	_jc_soot_grimp_internal_GAssignStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GAssignStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GAssignStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GAssignStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GAssignStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GAssignStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GAssignStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JAssignStmt$vmethods	soot_jimple_internal_JAssignStmt;
	_jc_soot_grimp_internal_GAssignStmt$vmethods	soot_grimp_internal_GAssignStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GAssignStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GAssignStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAssignStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GAssignStmt$refs {
    _jc_soot_grimp_internal_GAssignStmt$sub_refs	soot_grimp_internal_GAssignStmt;
    _jc_soot_jimple_internal_JAssignStmt$sub_refs	soot_jimple_internal_JAssignStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GAssignStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JAssignStmt$sub_nonrefs	soot_jimple_internal_JAssignStmt;
    _jc_soot_grimp_internal_GAssignStmt$sub_nonrefs	soot_grimp_internal_GAssignStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GAssignStmt$object {
	_jc_soot_grimp_internal_GAssignStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GAssignStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GAssignStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GAssignStmt$vtype _jc_soot_grimp_internal_GAssignStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GAssignStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GAssignStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GAssignStmt_H_ */
